# Welcome to gwcosmo

Gwcosmo: a package to estimate cosmological parameters using gravitational-wave observations. 


## Installation

The recommended method for installing gwcosmo is using pip. We recommend setting up a virtual environment first. Once you have done this and activated your virtual environment, simply run

```
pip install gwcosmo
```

Note that gwcosmo requires Python version 3.8 or higher.


## Documentation

Gwcosmo's documentation is available at [https://lscsoft.docs.ligo.org/gwcosmo/](https://lscsoft.docs.ligo.org/gwcosmo/).


## Citing gwcosmo 

If you use gwcosmo in a scientific publication, please cite the following publications, and include the following statement in your manuscript: "This work makes use of gwcosmo which is available at https://git.ligo.org/lscsoft/gwcosmo".

```bibtex
@ARTICLE{2023arXiv230802281G,
       author = {{Gray}, Rachel and {Beirnaert}, Freija and {Karathanasis}, Christos and {Revenu}, Beno{\^\i}t and {Turski}, Cezary and {Chen}, Anson and {Baker}, Tessa and {Vallejo}, Sergio and {Enea Romano}, Antonio and {Ghosh}, Tathagata and {Ghosh}, Archisman and {Leyde}, Konstantin and {Mastrogiovanni}, Simone and {More}, Surhud},
        title = "{Joint cosmological and gravitational-wave population inference using dark sirens and galaxy catalogues}",
      journal = {arXiv e-prints},
     keywords = {Astrophysics - Cosmology and Nongalactic Astrophysics},
         year = 2023,
        month = aug,
          eid = {arXiv:2308.02281},
        pages = {arXiv:2308.02281},
          doi = {10.48550/arXiv.2308.02281},
archivePrefix = {arXiv},
       eprint = {2308.02281},
 primaryClass = {astro-ph.CO},
       adsurl = {https://ui.adsabs.harvard.edu/abs/2023arXiv230802281G},
      adsnote = {Provided by the SAO/NASA Astrophysics Data System}
}

@article{10.1093/mnras/stac366,
    author = {Gray, R and Messenger, C and Veitch, J},
    title = "{A pixelated approach to galaxy catalogue incompleteness: improving the dark siren measurement of the Hubble constant}",
    journal = {Monthly Notices of the Royal Astronomical Society},
    volume = {512},
    number = {1},
    pages = {1127-1140},
    year = {2022},
    month = {02},
    issn = {0035-8711},
    doi = {10.1093/mnras/stac366},
    url = {https://doi.org/10.1093/mnras/stac366},
    eprint = {https://academic.oup.com/mnras/article-pdf/512/1/1127/45303118/stac366.pdf}
}

@article{PhysRevD.101.122001,
  title = {Cosmological inference using gravitational wave standard sirens: A mock data analysis},
  author = {Gray, Rachel and Hernandez, Ignacio Maga\~na and Qi, Hong and Sur, Ankan and Brady, Patrick R. and Chen, Hsin-Yu and Farr, Will M. and Fishbach, Maya and Gair, Jonathan R. and Ghosh, Archisman and Holz, Daniel E. and Mastrogiovanni, Simone and Messenger, Christopher and Steer, Dani\`ele A. and Veitch, John},
  journal = {Phys. Rev. D},
  volume = {101},
  issue = {12},
  pages = {122001},
  numpages = {22},
  year = {2020},
  month = {Jun},
  publisher = {American Physical Society},
  doi = {10.1103/PhysRevD.101.122001},
  url = {https://link.aps.org/doi/10.1103/PhysRevD.101.122001}
}
```
